@@ -5,6 +5,7 @@ import (
 	"encoding/json"
 	"errors"
 	"fmt"
+	"hash/fnv"
 	"os"
 	"path/filepath"
 	runtimelib "runtime"
@@ -16,6 +17,7 @@ import (
 	"github.com/jandedobbeleer/oh-my-posh/src/cache"
 	"github.com/jandedobbeleer/oh-my-posh/src/cli/upgrade"
 	"github.com/jandedobbeleer/oh-my-posh/src/log"
+	"github.com/jandedobbeleer/oh-my-posh/src/runtime/http"
 	"github.com/jandedobbeleer/oh-my-posh/src/runtime/path"
 
 	toml "github.com/pelletier/go-toml/v2"
@@ -34,7 +36,7 @@ func Load(configFile string, migrate bool) *Config {
 
 	configFile = resolveConfigLocation(configFile)
 
-	cfg := readConfig(configFile)
+	cfg := parseConfigFile(configFile)
 
 	// only migrate automatically when the switch isn't set
 	if !migrate && cfg.Version < Version {
@@ -71,6 +73,9 @@ func resolveConfigLocation(config string) string {
 		return url
 	}
 
+	// Clean the config path so it works regardless of the OS
+	config = filepath.ToSlash(config)
+
 	// Cygwin path always needs the full path as we're on Windows but not really.
 	// Doing filepath actions will convert it to a Windows path and break the init script.
 	if isCygwin() {
@@ -89,30 +94,86 @@ func resolveConfigLocation(config string) string {
 	return abs
 }
 
-func readConfig(configFile string) *Config {
+type hashWriter interface {
+	Write(p []byte) (n int, err error)
+}
+
+func parseConfigFile(configFile string) *Config {
+	defer log.Trace(time.Now())
+
+	configDSC := DSC()
+	configDSC.Load()
+	configDSC.Add(configFile)
+
+	defer configDSC.Save()
+
+	h := fnv.New64a()
+
+	cfg, err := readConfig(configFile, h)
+	if err != nil {
+		log.Error(err)
+		return Default(true)
+	}
+
+	parentFolder := filepath.Dir(configFile)
+
+	for cfg.Extends != "" {
+		cfg.Extends = resolvePath(cfg.Extends, parentFolder)
+		base, err := readConfig(cfg.Extends, h)
+		if err != nil {
+			log.Error(err)
+			break
+		}
+
+		configDSC.Add(cfg.Extends)
+
+		err = base.merge(cfg)
+		if err != nil {
+			log.Error(err)
+			break
+		}
+
+		cfg = base
+	}
+
+	cfg.hash = h.Sum64()
+
+	return cfg
+}
+
+func resolvePath(configFile, parentFolder string) string {
+	if url, OK := isTheme(configFile); OK {
+		return url
+	}
+
+	if strings.HasPrefix(configFile, "https://") {
+		return configFile
+	}
+
+	configFile = path.ReplaceTildePrefixWithHomeDir(configFile)
+
+	if filepath.IsAbs(configFile) {
+		return configFile
+	}
+
+	return filepath.Join(parentFolder, configFile)
+}
+
+func readConfig(configFile string, h hashWriter) (*Config, error) {
 	defer log.Trace(time.Now())
 
 	if configFile == "" {
 		log.Debug("no config file specified, using default")
-		return Default(false)
+		return Default(false), nil
 	}
 
 	var cfg Config
 	cfg.Source = configFile
 	cfg.Format = strings.TrimPrefix(filepath.Ext(configFile), ".")
 
-	getData := func(configFile string) ([]byte, error) {
-		if strings.HasPrefix(configFile, "https://") {
-			return download(configFile)
-		}
-
-		return os.ReadFile(configFile)
-	}
-
 	data, err := getData(configFile)
 	if err != nil {
-		log.Error(err)
-		return Default(true)
+		return nil, err
 	}
 
 	switch cfg.Format {
@@ -135,23 +196,23 @@ func readConfig(configFile string) *Config {
 	}
 
 	if err != nil {
-		log.Error(err)
-		return Default(true)
+		return nil, err
 	}
 
-	if cfg.Extends == "" {
-		return &cfg
-	}
-
-	basePath := resolveConfigLocation(cfg.Extends)
-
-	base := readConfig(basePath)
-	err = base.merge(&cfg)
+	_, err = h.Write(data)
 	if err != nil {
 		log.Error(err)
 	}
 
-	return base
+	return &cfg, nil
+}
+
+func getData(configFile string) ([]byte, error) {
+	if !strings.HasPrefix(configFile, "https://") {
+		return os.ReadFile(configFile)
+	}
+
+	return http.Download(configFile, true)
 }
 
 // isCygwin checks if we're running in Cygwin environment
